@@ -2,10 +2,17 @@
 #
 from __future__ import annotations
 
-from collections.abc import Collection, Generator, Iterator, Mapping
 from typing import (
     TYPE_CHECKING,
     Any,
+    Collection,
+    Dict,
+    Generator,
+    Iterator,
+    Mapping,
+    Optional,
+    Set,
+    Tuple,
     Union,
     overload,
 )
@@ -33,41 +40,40 @@ ANY: None = None
 
 
 class SimpleMemory(Store):
-    """\
-    A fast naive in memory implementation of a triple store.
+    """A fast naive in memory implementation of a triple store.
 
     This triple store uses nested dictionaries to store triples. Each
-    triple is stored in two such indices as follows spo[s][p][o] = 1 and
-    pos[p][o][s] = 1.
+    triple is stored in two such indices as follows `spo[s][p][o]` = 1 and
+    `pos[p][o][s]` = 1.
 
     Authors: Michel Pelletier, Daniel Krech, Stefan Niederhauser
     """
 
     def __init__(
         self,
-        configuration: str | None = None,
-        identifier: Identifier | None = None,
+        configuration: Optional[str] = None,
+        identifier: Optional[Identifier] = None,
     ):
         super(SimpleMemory, self).__init__(configuration)
         self.identifier = identifier
 
         # indexed by [subject][predicate][object]
-        self.__spo: dict[_SubjectType, dict[_PredicateType, dict[_ObjectType, int]]] = (
+        self.__spo: Dict[_SubjectType, Dict[_PredicateType, Dict[_ObjectType, int]]] = (
             {}
         )
 
         # indexed by [predicate][object][subject]
-        self.__pos: dict[_PredicateType, dict[_ObjectType, dict[_SubjectType, int]]] = (
+        self.__pos: Dict[_PredicateType, Dict[_ObjectType, Dict[_SubjectType, int]]] = (
             {}
         )
 
         # indexed by [predicate][object][subject]
-        self.__osp: dict[_ObjectType, dict[_SubjectType, dict[_PredicateType, int]]] = (
+        self.__osp: Dict[_ObjectType, Dict[_SubjectType, Dict[_PredicateType, int]]] = (
             {}
         )
 
-        self.__namespace: dict[str, URIRef] = {}
-        self.__prefix: dict[URIRef, str] = {}
+        self.__namespace: Dict[str, URIRef] = {}
+        self.__prefix: Dict[URIRef, str] = {}
 
     def add(
         self,
@@ -75,9 +81,7 @@ class SimpleMemory(Store):
         context: _ContextType,
         quoted: bool = False,
     ) -> None:
-        """\
-        Add a triple to the store of triples.
-        """
+        """Add a triple to the store of triples."""
         # add dictionary entries for spo[s][p][p] = 1 and pos[p][o][s]
         # = 1, creating the nested dictionaries where they do not yet
         # exits.
@@ -118,7 +122,7 @@ class SimpleMemory(Store):
     def remove(
         self,
         triple_pattern: _TriplePatternType,
-        context: _ContextType | None = None,
+        context: Optional[_ContextType] = None,
     ) -> None:
         for (subject, predicate, object), c in list(self.triples(triple_pattern)):
             del self.__spo[subject][predicate][object]
@@ -128,8 +132,8 @@ class SimpleMemory(Store):
     def triples(
         self,
         triple_pattern: _TriplePatternType,
-        context: _ContextType | None = None,
-    ) -> Iterator[tuple[_TripleType, Iterator[_ContextType | None]]]:
+        context: Optional[_ContextType] = None,
+    ) -> Iterator[Tuple[_TripleType, Iterator[Optional[_ContextType]]]]:
         """A generator over all the triples matching"""
         subject, predicate, object = triple_pattern
         if subject != ANY:  # subject is given
@@ -189,7 +193,7 @@ class SimpleMemory(Store):
                     for o in subjectDictionary[p].keys():
                         yield (s, p, o), self.__contexts()
 
-    def __len__(self, context: _ContextType | None = None) -> int:
+    def __len__(self, context: Optional[_ContextType] = None) -> int:
         # @@ optimize
         i = 0
         for triple in self.triples((None, None, None)):
@@ -212,22 +216,22 @@ class SimpleMemory(Store):
             self.__prefix[namespace] = prefix
             self.__namespace[prefix] = namespace
         else:
-            # type error: Invalid index type "Optional[URIRef]" for "dict[URIRef, str]"; expected type "URIRef"
+            # type error: Invalid index type "Optional[URIRef]" for "Dict[URIRef, str]"; expected type "URIRef"
             self.__prefix[_coalesce(bound_namespace, namespace)] = _coalesce(  # type: ignore[index]
                 bound_prefix, default=prefix
             )
-            # type error: Invalid index type "Optional[str]" for "dict[str, URIRef]"; expected type "str"
+            # type error: Invalid index type "Optional[str]" for "Dict[str, URIRef]"; expected type "str"
             self.__namespace[_coalesce(bound_prefix, prefix)] = _coalesce(  # type: ignore[index]
                 bound_namespace, default=namespace
             )
 
-    def namespace(self, prefix: str) -> URIRef | None:
+    def namespace(self, prefix: str) -> Optional[URIRef]:
         return self.__namespace.get(prefix, None)
 
-    def prefix(self, namespace: URIRef) -> str | None:
+    def prefix(self, namespace: URIRef) -> Optional[str]:
         return self.__prefix.get(namespace, None)
 
-    def namespaces(self) -> Iterator[tuple[str, URIRef]]:
+    def namespaces(self) -> Iterator[Tuple[str, URIRef]]:
         for prefix, namespace in self.__namespace.items():
             yield prefix, namespace
 
@@ -263,8 +267,7 @@ class SimpleMemory(Store):
 
 
 class Memory(Store):
-    """\
-    An in memory implementation of a triple store.
+    """An in memory implementation of a triple store.
 
     Same as SimpleMemory above, but is Context-aware, Graph-aware, and Formula-aware
     Authors: Ashley Sommer
@@ -276,36 +279,36 @@ class Memory(Store):
 
     def __init__(
         self,
-        configuration: str | None = None,
-        identifier: Identifier | None = None,
+        configuration: Optional[str] = None,
+        identifier: Optional[Identifier] = None,
     ):
         super(Memory, self).__init__(configuration)
         self.identifier = identifier
 
         # indexed by [subject][predicate][object]
-        self.__spo: dict[_SubjectType, dict[_PredicateType, dict[_ObjectType, int]]] = (
+        self.__spo: Dict[_SubjectType, Dict[_PredicateType, Dict[_ObjectType, int]]] = (
             {}
         )
 
         # indexed by [predicate][object][subject]
-        self.__pos: dict[_PredicateType, dict[_ObjectType, dict[_SubjectType, int]]] = (
+        self.__pos: Dict[_PredicateType, Dict[_ObjectType, Dict[_SubjectType, int]]] = (
             {}
         )
 
         # indexed by [predicate][object][subject]
-        self.__osp: dict[_ObjectType, dict[_SubjectType, dict[_PredicateType, int]]] = (
+        self.__osp: Dict[_ObjectType, Dict[_SubjectType, Dict[_PredicateType, int]]] = (
             {}
         )
 
-        self.__namespace: dict[str, URIRef] = {}
-        self.__prefix: dict[URIRef, str] = {}
-        self.__context_obj_map: dict[str, Graph] = {}
-        self.__tripleContexts: dict[_TripleType, dict[str | None, bool]] = {}
-        self.__contextTriples: dict[str | None, set[_TripleType]] = {None: set()}
+        self.__namespace: Dict[str, URIRef] = {}
+        self.__prefix: Dict[URIRef, str] = {}
+        self.__context_obj_map: Dict[str, Graph] = {}
+        self.__tripleContexts: Dict[_TripleType, Dict[Optional[str], bool]] = {}
+        self.__contextTriples: Dict[Optional[str], Set[_TripleType]] = {None: set()}
         # all contexts used in store (unencoded)
-        self.__all_contexts: set[Graph] = set()
+        self.__all_contexts: Set[Graph] = set()
         # default context information for triples
-        self.__defaultContexts: dict[str | None, bool] | None = None
+        self.__defaultContexts: Optional[Dict[Optional[str], bool]] = None
 
     def add(
         self,
@@ -313,9 +316,7 @@ class Memory(Store):
         context: _ContextType,
         quoted: bool = False,
     ) -> None:
-        """\
-        Add a triple to the store of triples.
-        """
+        """Add a triple to the store of triples."""
         # add dictionary entries for spo[s][p][p] = 1 and pos[p][o][s]
         # = 1, creating the nested dictionaries where they do not yet
         # exits.
@@ -372,7 +373,7 @@ class Memory(Store):
     def remove(
         self,
         triple_pattern: _TriplePatternType,
-        context: _ContextType | None = None,
+        context: Optional[_ContextType] = None,
     ) -> None:
         req_ctx = self.__ctx_to_str(context)
         for triple, c in self.triples(triple_pattern, context=context):
@@ -410,9 +411,9 @@ class Memory(Store):
     def triples(
         self,
         triple_pattern: _TriplePatternType,
-        context: _ContextType | None = None,
+        context: Optional[_ContextType] = None,
     ) -> Generator[
-        tuple[_TripleType, Generator[_ContextType | None, None, None]],
+        Tuple[_TripleType, Generator[Optional[_ContextType], None, None]],
         None,
         None,
     ]:
@@ -430,7 +431,7 @@ class Memory(Store):
 
         # optimize "triple in graph" case (all parts given)
         elif subject is not None and predicate is not None and object_ is not None:
-            # type error: Incompatible types in assignment (expression has type "tuple[Optional[IdentifiedNode], Optional[IdentifiedNode], Optional[Identifier]]", variable has type "tuple[IdentifiedNode, IdentifiedNode, Identifier]")
+            # type error: Incompatible types in assignment (expression has type "Tuple[Optional[IdentifiedNode], Optional[IdentifiedNode], Optional[Identifier]]", variable has type "Tuple[IdentifiedNode, IdentifiedNode, Identifier]")
             # NOTE on type error: at this point, all elements of triple_pattern
             # is not None, so it has the same type as triple
             triple = triple_pattern  # type: ignore[assignment]
@@ -531,31 +532,31 @@ class Memory(Store):
             self.__prefix[namespace] = prefix
             self.__namespace[prefix] = namespace
         else:
-            # type error: Invalid index type "Optional[URIRef]" for "dict[URIRef, str]"; expected type "URIRef"
+            # type error: Invalid index type "Optional[URIRef]" for "Dict[URIRef, str]"; expected type "URIRef"
             self.__prefix[_coalesce(bound_namespace, namespace)] = _coalesce(  # type: ignore[index]
                 bound_prefix, default=prefix
             )
-            # type error: Invalid index type "Optional[str]" for "dict[str, URIRef]"; expected type "str"
+            # type error: Invalid index type "Optional[str]" for "Dict[str, URIRef]"; expected type "str"
             # type error: Incompatible types in assignment (expression has type "Optional[URIRef]", target has type "URIRef")
             self.__namespace[_coalesce(bound_prefix, prefix)] = _coalesce(  # type: ignore[index]
                 bound_namespace, default=namespace
             )
 
-    def namespace(self, prefix: str) -> URIRef | None:
+    def namespace(self, prefix: str) -> Optional[URIRef]:
         return self.__namespace.get(prefix, None)
 
-    def prefix(self, namespace: URIRef) -> str | None:
+    def prefix(self, namespace: URIRef) -> Optional[str]:
         return self.__prefix.get(namespace, None)
 
-    def namespaces(self) -> Iterator[tuple[str, URIRef]]:
+    def namespaces(self) -> Iterator[Tuple[str, URIRef]]:
         for prefix, namespace in self.__namespace.items():
             yield prefix, namespace
 
     def contexts(
-        self, triple: _TripleType | None = None
+        self, triple: Optional[_TripleType] = None
     ) -> Generator[_ContextType, None, None]:
         if triple is None or triple == (None, None, None):
-            return (context for context in self.__all_contexts)
+            return (context for context in list(self.__all_contexts))
 
         subj, pred, obj = triple
         try:
@@ -564,7 +565,7 @@ class Memory(Store):
         except KeyError:
             return (_ for _ in [])
 
-    def __len__(self, context: _ContextType | None = None) -> int:
+    def __len__(self, context: Optional[_ContextType] = None) -> int:
         ctx = self.__ctx_to_str(context)
         if ctx not in self.__contextTriples:
             return 0
@@ -591,7 +592,7 @@ class Memory(Store):
         self,
         triple: _TripleType,
         triple_exists: bool,
-        context: _ContextType | None,
+        context: Optional[_ContextType],
         quoted: bool,
     ) -> None:
         """add the given context to the set of contexts for the triple"""
@@ -604,7 +605,7 @@ class Memory(Store):
             except KeyError:
                 # triple exists with default ctx info
                 # start with a copy of the default ctx info
-                # type error: Item "None" of "Optional[dict[Optional[str], bool]]" has no attribute "copy"
+                # type error: Item "None" of "Optional[Dict[Optional[str], bool]]" has no attribute "copy"
                 triple_context = self.__tripleContexts[triple] = (
                     self.__defaultContexts.copy()  # type: ignore[union-attr]
                 )
@@ -642,27 +643,27 @@ class Memory(Store):
 
     def __get_context_for_triple(
         self, triple: _TripleType, skipQuoted: bool = False  # noqa: N803
-    ) -> Collection[str | None]:
+    ) -> Collection[Optional[str]]:
         """return a list of contexts (str) for the triple, skipping
         quoted contexts if skipQuoted==True"""
 
         ctxs = self.__tripleContexts.get(triple, self.__defaultContexts)
 
         if not skipQuoted:
-            # type error: Item "None" of "Optional[dict[Optional[str], bool]]" has no attribute "keys"
+            # type error: Item "None" of "Optional[Dict[Optional[str], bool]]" has no attribute "keys"
             return ctxs.keys()  # type: ignore[union-attr]
 
-        # type error: Item "None" of "Optional[dict[Optional[str], bool]]" has no attribute "items"
+        # type error: Item "None" of "Optional[Dict[Optional[str], bool]]" has no attribute "items"
         return [ctx for ctx, quoted in ctxs.items() if not quoted]  # type: ignore[union-attr]
 
-    def __triple_has_context(self, triple: _TripleType, ctx: str | None) -> bool:
+    def __triple_has_context(self, triple: _TripleType, ctx: Optional[str]) -> bool:
         """return True if the triple exists in the given context"""
-        # type error: Unsupported right operand type for in ("Optional[dict[Optional[str], bool]]")
+        # type error: Unsupported right operand type for in ("Optional[Dict[Optional[str], bool]]")
         return ctx in self.__tripleContexts.get(triple, self.__defaultContexts)  # type: ignore[operator]
 
     def __remove_triple_context(self, triple: _TripleType, ctx):
         """remove the context from the triple"""
-        # type error: Item "None" of "Optional[dict[Optional[str], bool]]" has no attribute "copy"
+        # type error: Item "None" of "Optional[Dict[Optional[str], bool]]" has no attribute "copy"
         ctxs = self.__tripleContexts.get(triple, self.__defaultContexts).copy()  # type: ignore[union-attr]
         del ctxs[ctx]
         if ctxs == self.__defaultContexts:
@@ -677,7 +678,7 @@ class Memory(Store):
     @overload
     def __ctx_to_str(self, ctx: None) -> None: ...
 
-    def __ctx_to_str(self, ctx: _ContextType | None) -> str | None:
+    def __ctx_to_str(self, ctx: Optional[_ContextType]) -> Optional[str]:
         if ctx is None:
             return None
         try:
